	****************************************************************************
	*******************	Investment Climate Unit - ETIIC		********************
	*******************	Creation date: September, 10 2024	********************
	*******************	Last version: September, 16 2024	********************
	*******************	Project: Reproducibility Green		********************
	*******************	File: figure 3_1.do					********************	
	****************************************************************************
	// Get the current date and format it as YYYYMMDD
	local today = c(current_date)
	local today_formatted = subinstr("`today'", " ", "", .)  // Remove spaces (default format is like "06 Sep 2024")
	local today_formatted = subinstr("`today_formatted'", " ", "", .)  // Ensures no spaces in other date formats
	
	use "$edited_data/Clean GTI GTP Database - `today_formatted'.dta", clear
	
	** Defining the period of analysis
	drop if tax_year>2020
	
	collapse (count) other_cond (sum) d_add_green d_add_greening d_dirty_polluting_ti, by(tax_year)
	
	rename other_cond total_incentives
	
	gen share_green  	=	d_add_green/total_incentives
	gen share_greening	=	d_add_greening/total_incentives
	gen share_dirty		=	d_dirty_polluting_ti/total_incentives
	
	label variable share_green 		"% of incentives that are green sector-oriented"
	label variable share_greening 	"% of incentives that are green process-oriented"
	label variable share_dirty		"% of incentives for polluting sectors"
	label variable total_incentives	"Total number of incentives"

	
			  
	* Create adjusted variables for positioning the bars side-by-side
	gen tax_year_green = tax_year - 0.3
	gen tax_year_greening = tax_year
	gen tax_year_dirty = tax_year + 0.3
	
	* Create a  bar graph with shares and line graph
	twoway (bar share_green tax_year_green, fcolor(green) lcolor(none) barwidth(0.3)) ///
       (bar share_greening tax_year_greening, fcolor(lime) lcolor(none) barwidth(0.3)) ///
       (bar share_dirty tax_year_dirty, fcolor(cranberry) lcolor(none) barwidth(0.3)) ///
       (line total_incentives tax_year, lcolor(black) lwidth(medium) yaxis(2)), ///
       legend(label(1 "% of incentives that are green sector-oriented") label(2 "% of incentives that are green process-oriented") label(3 "% of incentives for polluting sectors") ///
              label(4 "Total number of incentives") size(vsmall) position(6) colfirst) ///
		ytitle("% of total CIT incentives", size(vsmall)) ylabel(0 "0%" 0.01 "1%" 0.02 "2%" 0.03 "3%" 0.04 "4%" 0.05 "5%" 0.06 "6%" 0.07 "7%" 0.08 "8%" 0.09 "9%" 0.10 "10%",  notick labsize(small)) ///
		ytitle("Total number of CIT incentives", axis(2) size(small)) ylabel(0(500)3000, axis(2)  notick  labsize(vsmall) nogrid ) ///
		yscale( lc(white) ) ///
		yscale( axis(2) lc(white)) ///
		xtitle("") xlabel(2009(1)2020, labsize(small) nogrid) ///
		title("Figure 3.1. Prevalence of green and polluting incentives" ///
		"(as a share of total CIT incentives), across economies, 2009-20")
		
		graph export "$graphs\graph_3_1.png", replace
		putexcel set "$output\Green Paper Output.xlsx", sheet("graphs 3.1") modify
		putexcel A1 = picture("$graphs\graph_3_1.png") 
		
