	****************************************************************************
	*******************	Investment Climate Unit - ETIIC		********************
	*******************	Creation date: September, 10 2024	********************
	*******************	Last version: September, 16 2024	********************
	*******************	Project: Reproducibility Green		********************
	*******************	File: figure 3_10.do					********************	
	****************************************************************************
	// Get the current date and format it as YYYYMMDD
	local today = c(current_date)
	local today_formatted = subinstr("`today'", " ", "", .)  // Remove spaces (default format is like "06 Sep 2024")
	local today_formatted = subinstr("`today_formatted'", " ", "", .)  // Ensures no spaces in other date formats
	
	use "$edited_data/Clean GTI GTP Database - `today_formatted'.dta", clear
	
	** Defining the period and regions of analysis
	drop if  tax_year>2020
	gen 	incentive_type = taxparinc
	replace incentive_type = "Accelarated depreciation" 			if strpos(taxparinc, "Accelerated ")>0
	replace incentive_type = "Extended Loss Carry Forward/Backward" if strpos(taxparinc, "Extended ")   >0
	replace incentive_type = "Reduced tax rate" 					if strpos(taxparinc, "Reduced ")    >0
	
	drop if incentive_type == "Tax delay /Early refund"
	collapse (count) other_cond (sum) d_add_green d_add_greening d_dirty_polluting_ti, by(tax_year incentive_type)

	bysort tax_year: egen dirty_total	=	total(d_dirty_polluting_ti)
	
	gen share_dirty_total 	=   d_dirty_polluting_ti/dirty_total
	
	gen Accelarated	= share_dirty_total if incentive_type == "Accelarated depreciation"
	gen Extended 	= share_dirty_total if incentive_type == "Extended Loss Carry Forward/Backward"
	gen Patent		= share_dirty_total if incentive_type == "Patent box"
	gen Reduced		= share_dirty_total if incentive_type == "Reduced tax rate"
	gen Credit		= share_dirty_total if incentive_type == "Tax credit"
	gen Deduction	= share_dirty_total if incentive_type == "Tax deduction"
	gen Holiday		= share_dirty_total if incentive_type == "Tax holiday"
	
	bysort tax_year: egen accelarated 	= max(Accelarated)
	bysort tax_year: egen extended 		= max(Extended)
	bysort tax_year: egen patent 		= max(Patent)
	bysort tax_year: egen reduced 		= max(Reduced)
	bysort tax_year: egen credit 		= max(Credit)
	bysort tax_year: egen deduction 	= max(Deduction)
	bysort tax_year: egen holiday 		= max(Holiday)
	
	label variable accelarated	"Accelarated depreciation"
	label variable extended		"Extended Loss Carry Forward/Backward"
	label variable patent		"Patent box"
	label variable reduced		"Reduced tax rate"
	label variable credit		"Tax credit"
	label variable deduction	"Tax deduction"
	label variable holiday		"Tax holiday"
	
	keep  tax_year accelarated extended patent reduced credit deduction holiday
	duplicates drop
	
	graph bar accelarated holiday reduced deduction credit extended patent, over(tax_year, label(labsize(vsmall)) gap(5)) stack ///
		legend(order(1 "Accelarated depreciation" 2 "Tax holiday" 3 "Reduced tax rate" 4 "Tax deduction" ///
		5 "Tax credit" 6 "Extended Loss Carry Forward/Backward" 7 "Patent box") size(small) pos(6) row(3) col(3)) ///
		yscale( lc(white) ) ///
		ylabel(0 "0%" 0.1 "10%" 0.2 "20%" 0.3 "30%" 0.4 "40%" 0.5 "10%" 0.6 "60%" ///
		0.7 "70%" 0.8 "80%" 0.9 "90%" 1 "100%",  labsize(vsmall) notick) ///
		ytitle("Share (as a % of total polluting incentives)", size(small) ) ///
		title("Figure 3.10. Prevalence of different CIT" "instruments for polluting incentives") ///
		plotregion(margin(0 0 0 5))
 
	graph export "$graphs\graph_3_10.png", replace
	putexcel set "$output\Green Paper Output.xlsx", sheet("graphs 3.10") modify
	putexcel A1 = picture("$graphs\graph_3_10.png") 
	