	****************************************************************************
	*******************	Investment Climate Unit - ETIIC		********************
	*******************	Creation date: September, 10 2024	********************
	*******************	Last version: September, 16 2024	********************
	*******************	Project: Reproducibility Green		********************
	*******************	File: figure 3_11.do				********************	
	****************************************************************************
	// Get the current date and format it as YYYYMMDD
	local today = c(current_date)
	local today_formatted = subinstr("`today'", " ", "", .)  // Remove spaces (default format is like "06 Sep 2024")
	local today_formatted = subinstr("`today_formatted'", " ", "", .)  // Ensures no spaces in other date formats
	
	use "$edited_data/Clean GTI GTP Database - `today_formatted'.dta", clear

	** Defining the period and regions of analysis
	drop if  tax_year>2020
	
	* Figure 3.11. Average length of tax holidays for green, polluting, and other CIT incentives, 2009-20
	* Only tax holidays with sunset clause
	
	** Keep only Tax Holidays
	keep if taxparinc == "Tax holiday"
	** Exclude indefinite tax holidays
	drop if inlist(generosity_years, 9998,9999)
	
	 collapse (mean) generosity_years, by(tax_year d_add_green d_add_greening d_dirty_polluting_ti)

 
	 twoway (line generosity_years tax_year if d_dirty_polluting_ti == 1 & d_add_green == 0 & d_add_greening == 0) ///
			(line generosity_years tax_year if d_dirty_polluting_ti == 0 & d_add_green == 1 & d_add_greening == 0) ///
			(line generosity_years tax_year if d_dirty_polluting_ti == 0 & d_add_green == 0 & d_add_greening == 1) ///
			(line generosity_years tax_year if d_dirty_polluting_ti == 0 & d_add_green == 0 & d_add_greening == 0) , ///
			legend(order(1 "Polluting incentives" 2 "Green sector-oriented incentives" ///
			3 "Green process-oriented incentives" 4 "Other Incentives") size(small) pos(6) row(2) col(2) ) ///
			yscale( lc(white) ) ///
			ylabel(0(2)20, labsize(vsmall) notick) ///
			ytitle("Average length of tax holiday (number of years)", margin(-1 0 0 0) size(small) ) ///
			xlabel(2009(1)2020,  labsize(vsmall) notick) ///
			xtitle("") ///
			title("Figure 3.11. Average length of tax holidays for green," "polluting, and other CIT incentives, 2009-20") ///
			plotregion(margin(5 0 0 5))
			
	graph export "$graphs\graph_3_11.png", replace
	putexcel set "$output\Green Paper Output.xlsx", sheet("graphs 3.11") modify 
	putexcel A1 = picture("$graphs\graph_3_11.png") 
	