	****************************************************************************
	*******************	Investment Climate Unit - ETIIC		********************
	*******************	Creation date: September, 10 2024	********************
	*******************	Last version: September, 16 2024	********************
	*******************	Project: Reproducibility Green		********************
	*******************	File: figure 3_12.do					********************	
	****************************************************************************
	// Get the current date and format it as YYYYMMDD
	local today = c(current_date)
	local today_formatted = subinstr("`today'", " ", "", .)  // Remove spaces (default format is like "06 Sep 2024")
	local today_formatted = subinstr("`today_formatted'", " ", "", .)  // Ensures no spaces in other date formats
	
	use "$edited_data/Clean GTI GTP Database - `today_formatted'.dta", clear
	
	** Defining the period and regions of analysis
	drop if  tax_year>2020
	gen 	incentive_type = taxparinc
	replace incentive_type = "Accelarated depreciation" 			if strpos(taxparinc, "Accelerated ")>0
	replace incentive_type = "Extended Loss Carry Forward/Backward" if strpos(taxparinc, "Extended ")   >0
	replace incentive_type = "Reduced tax rate" 					if strpos(taxparinc, "Reduced ")    >0
	
	drop if incentive_type == "Tax delay /Early refund"
	
	gen green = 1 if d_add_green == 1 | d_add_greening == 1
	
	* Profit-based: tax holiday/tax exemption; Reduced tax rate; extended loss carry forward/backward; patent box
	gen profit_base = 1 if inlist(incentive_type, "Tax holiday", "Reduced tax rate", "Extended Loss Carry Forward/Backward", "Patent box")
	
	* Cost-based: accelerated depreciation; tax deduction>100%; tax credit
	gen cost_base   = 1 if inlist(incentive_type, "Accelarated depreciation", "Tax deduction", "Tax credit")
	
	collapse (count) other_cond (sum) profit_base cost_base, by(tax_year green d_dirty_polluting_ti)
	
	gen share_profit = profit_base/other_cond
	gen share_cost	 = cost_base/other_cond
	
	
	* Green
	graph 	bar share_cost share_profit if green == 1, over(tax_year, label(labsize(small) angle(90)) gap(5)) stack ///
		  	legend(order(1 "Cost-based" 2 "Profit-based") size(small) pos(6) row(1) col(2)) ///
			bar(1,  color("0 100 0")) ///
			bar(2,  color("144 238 144")) ///
			yscale( lc(white) ) ///
			ylabel(0 "0%" 0.1 "10%" 0.2 "20%" 0.3 "30%" 0.4 "40%" 0.5 "50%" 0.6 "60%" ///
			0.7 "70%" 0.8 "80%" 0.9 "90%" 1 "100%",  labsize(small) notick) ///
			ytitle("Share (as a % of green incentives)", size(small) ) ///
			title("a. Green incentives", size(small)) ///
		plotregion(margin(0 0 0 5))
		graph save "$graphs\green_incentives", replace
		
	* Brown		
	graph 	bar share_cost share_profit if d_dirty_polluting_ti == 1, over(tax_year, label(labsize(small) angle(90)) gap(5)) stack ///
			legend(order(1 "Cost-based" 2 "Profit-based") size(small) pos(6) row(1) col(2)) ///
			bar(1,  color("128 0   0")) ///
			bar(2,  color("255 160 122")) ///
			yscale( lc(white) ) ///
			ylabel(0 "0%" 0.1 "10%" 0.2 "20%" 0.3 "30%" 0.4 "40%" 0.5 "50%" 0.6 "60%" ///
			0.7 "70%" 0.8 "80%" 0.9 "90%" 1 "100%",  labsize(small) notick) ///
			ytitle("Share (as a % of polluting incentives)", size(small) ) ///
			title("b. Polluting incentives", size(small)) ///
		plotregion(margin(0 0 0 5))
	graph save "$graphs\polluting_incentives", replace
		
	* Combine the two graphs side by side
	graph combine "$graphs\green_incentives.gph" "$graphs\polluting_incentives.gph", ///
		title("Figure 3.12. Prevalence of profit-based versus cost-based incentives") ///
		colfirst

	* Delete the saved individual graphs
	erase "$graphs\green_incentives.gph"
	erase "$graphs\polluting_incentives.gph"
	
	graph export "$graphs\graph_3_12.png", replace
	putexcel set "$output\Green Paper Output.xlsx", sheet("graphs 3.12") modify
	putexcel A1 = picture("$graphs\graph_3_12.png") 
	