	****************************************************************************
	*******************	Investment Climate Unit - ETIIC		********************
	*******************	Creation date: September, 10 2024	********************
	*******************	Last version: September, 16 2024	********************
	*******************	Project: Reproducibility Green		********************
	*******************	File: figure 3_2.do					********************	
	****************************************************************************
	// Get the current date and format it as YYYYMMDD
	local today = c(current_date)
	local today_formatted = subinstr("`today'", " ", "", .)  // Remove spaces (default format is like "06 Sep 2024")
	local today_formatted = subinstr("`today_formatted'", " ", "", .)  // Ensures no spaces in other date formats
	
	use "$edited_data/Clean GTI GTP Database - `today_formatted'.dta", clear
	
	** Defining the period of analysis
	drop if tax_year>2020
	
	
	collapse (count) other_cond (sum) d_add_green d_add_greening d_dirty_polluting_ti, by(country country_code)
	
	rename other_cond total_incentives
	
	gen share_green  		=	d_add_green/total_incentives
	gen share_greening		=	d_add_greening/total_incentives
	gen share_dirty			=	d_dirty_polluting_ti/total_incentives
	gen share_green_total 	=   share_green + share_greening
	
	label variable share_green 		"% of incentives that are green sector-oriented"
	label variable share_greening 	"% of incentives that are green process-oriented"
	label variable share_dirty		"% of incentives for polluting sectors"
	label variable total_incentives	"Total number of incentives"
	
	* Step 1: Sort the data based on share_green_total in descending order
	gsort share_green_total

	* Step 2: Create an index variable for sorting purposes
	gen sort_order = _n
	
	* Create a stacked bar graph with shares
	
	graph bar share_green share_greening, over(country, sort(sort_order) gap(0) label(labsize(small) angle(90))) stack ///
		bar(1, color(green)) ///
		bar(2, color(lime)) ///
		legend(label(1 "% of incentives that are green sector-oriented") ///
			label(2 "% of incentives that are green process-oriented") pos(6) ///
			col(2) size(small) region(lstyle(none))) ///
		yscale( lc(white) ) ///
		ylabel(0 "0%" 0.05 "5%" 0.1 "10%" 0.15 "15%" 0.2 "20%" 0.25 "25%" 0.3 "30%" 0.35 "35%", labsize(vsmall) notick) ///
		ytitle("% of total CIT incentives", size(vsmall)) ///
		title("Figure 3.2. Prevalence of green incentives" "(as a share of total CIT incentives), by economy") ///
		plotregion(margin(0 10 0 10))
		
		graph export "$graphs\graph_3_2.png", replace
		putexcel set "$output\Green Paper Output.xlsx", sheet("graphs 3.2") modify
		putexcel A1 = picture("$graphs\graph_3_2.png") 
	