	****************************************************************************
	*******************	Investment Climate Unit - ETIIC		********************
	*******************	Creation date: September, 10 2024	********************
	*******************	Last version: September, 16 2024	********************
	*******************	Project: Reproducibility Green		********************
	*******************	File: figure 3_4.do					********************	
	****************************************************************************
	// Get the current date and format it as YYYYMMDD
	local today = c(current_date)
	local today_formatted = subinstr("`today'", " ", "", .)  // Remove spaces (default format is like "06 Sep 2024")
	local today_formatted = subinstr("`today_formatted'", " ", "", .)  // Ensures no spaces in other date formats
	
	use "$edited_data/Clean GTI GTP Database - `today_formatted'.dta", clear
	
	** Defining the period of analysis
	drop if tax_year>2020
	
	* Step 1: Tag unique values of countries 
	egen tag = tag(country_code)

	* Step 2: Count the number of unique values by totaling the tagged observations
	egen num_unique = total(tag)

	* Step 3: Drop the temporary tag variable (optional)
	drop tag
	
	collapse (mean) num_unique (count) other_cond (sum) d_add_green d_add_greening d_dirty_polluting_ti, by(country_code)  
	
	rename other_cond total_incentives
	
	gen average_green  		=	d_add_green/12
	gen average_greening	=	d_add_greening/12
	gen average_green_total	=	(d_add_green+d_add_greening)/12
	gen average_dirty		=	d_dirty_polluting_ti/12
	
	label variable average_green 		"Average number of green sector-oriented incentives"
	label variable average_greening 	"Average number of green process-oriented incentives"
	label variable average_greening 	"Average number of green incentives"
	label variable average_dirty		"Average number of  polluting incentives"
	label variable total_incentives		"Total number of incentives"
	label variable num_unique			"Number of countries in the sample"
		
	twoway 	(scatter average_dirty average_green_total, mcolor(green) msize(medium)) ///
			(lfit average_dirty average_green_total, lcolor(cyan) lpattern(dash)), ///
			legend(off) ///
			xtitle("Average number of green incentives", size(vsmall)) ///
			xlabel(, labsize(vsmall)) ///
			ytitle("Average number of polluting incentives", size(vsmall)) ///
			ylabel(, labsize(vsmall)) ///
			title("Figure 3.4. Comparison of green and polluting" "CIT incentives, by economy") ///
		plotregion(margin(0 10 0 10))
		
	graph export "$graphs\graph_3_4.png", replace
	putexcel set "$output\Green Paper Output.xlsx", sheet("graphs 3.4") modify
	putexcel A1 = picture("$graphs\graph_3_4.png") 