	****************************************************************************
	*******************	Investment Climate Unit - ETIIC		********************
	*******************	Creation date: September, 10 2024	********************
	*******************	Last version: September, 16 2024	********************
	*******************	Project: Reproducibility Green		********************
	*******************	File: figure 3_5.do					********************	
	****************************************************************************
	// Get the current date and format it as YYYYMMDD
	local today = c(current_date)
	local today_formatted = subinstr("`today'", " ", "", .)  // Remove spaces (default format is like "06 Sep 2024")
	local today_formatted = subinstr("`today_formatted'", " ", "", .)  // Ensures no spaces in other date formats
	
	use "$edited_data/Clean GTI GTP Database - `today_formatted'.dta", clear
	
	** Defining the period and regions of analysis
	drop if tax_year>2020
	drop if region == "North America" | region == "Middle East and North Africa"
	replace region =  "Sub-Saharan Africa" if region == "Sub-saharan Africa"
	collapse (count) other_cond (sum) d_add_green d_add_greening d_dirty_polluting_ti, by(tax_year region)
	
	rename other_cond total_incentives
	
	gen share_green  		=	d_add_green/total_incentives
	gen share_greening		=	d_add_greening/total_incentives
	gen share_dirty			=	d_dirty_polluting_ti/total_incentives
	gen share_green_total 	=   (share_green + share_greening)
	
	label variable share_green 		"% of incentives that are green sector-oriented"
	label variable share_greening 	"% of incentives that are green process-oriented"
	label variable share_dirty		"% of incentives for polluting sectors"
	label variable total_incentives	"Total number of incentives"
	
	* Create a stacked bar graph with shares

	graph bar share_green_total, over(tax_year, gap(0)) ///
		over(region, gap(5) label(labsize(vsmall))) ///
	    asyvars bar(1, lcolor(none) lwidth(medium)) ///
		bar(1,  color("237 237 233")) ///
		bar(2,  color("218 218 210")) ///
		bar(3,  color("200 200 188")) ///
		bar(4,  color("182 182 165")) ///
		bar(5,  color("163 163 143")) ///
		bar(6,  color("145 145 120")) ///
		bar(7,  color("123 123 101")) ///
		bar(8,  color("101 101 83")) ///
		bar(9,  color("79  79  64")) ///
		bar(10, color("56  56  46")) ///
		bar(11, color("34  34  28")) ///
		bar(12, color("11  11  9")) ///
		legend(order(1 "2009" 2 "2010" 3 "2011" 4 "2012" 5 "2013" 6 "2014" 7 "2015" 8 "2016" 9 "2017" 10 "2018" 11 "2019" 12 "2020") ///
		size(vsmall) pos(6) row(1)) ///
		yscale( lc(white) ) ///
		ylabel(0 "0%" 0.02 "2%" 0.04 "4%" 0.06 "6%" 0.08 "8%" 0.10 "10%" 0.12 "12%", labsize(vsmall) notick) ///
		ytitle("Share of green incentives" "(as a % of total CIT incentives)", margin(-3 0 0 0) size(vsmall)) ///
		title("Figure 3.5. Prevalence of green incentives" "(as a share of total CIT incentives), by region, 2009–20") ///
		plotregion(margin(0 0 0 5))
		
		graph export "$graphs\graph_3_5.png", replace
		putexcel set "$output\Green Paper Output.xlsx", sheet("graphs 3.5") modify
		putexcel A1 = picture("$graphs\graph_3_5.png") 
		