	****************************************************************************
	*******************	Investment Climate Unit - ETIIC		********************
	*******************	Creation date: September, 10 2024	********************
	*******************	Last version: September, 16 2024	********************
	*******************	Project: Reproducibility Green		********************
	*******************	File: figure 3_6.do					********************	
	****************************************************************************
	// Get the current date and format it as YYYYMMDD
	local today = c(current_date)
	local today_formatted = subinstr("`today'", " ", "", .)  // Remove spaces (default format is like "06 Sep 2024")
	local today_formatted = subinstr("`today_formatted'", " ", "", .)  // Ensures no spaces in other date formats
	
	use "$edited_data/Clean GTI GTP Database - `today_formatted'.dta", clear
	
	** Defining the period and regions of analysis
	drop if  tax_year>2020
	drop if  region == "North America" | region == "Middle East and North Africa"
	replace  region =  "Sub-Saharan Africa" if region == "Sub-saharan Africa"
	collapse (count) other_cond (sum) d_add_green d_add_greening d_dirty_polluting_ti, by(tax_year region)
	
	rename other_cond total_incentives
	
	gen share_green  		=	d_add_green/total_incentives
	gen share_greening		=	d_add_greening/total_incentives
	gen share_dirty			=	d_dirty_polluting_ti/total_incentives
	gen share_green_total 	=   (share_green + share_greening)
	
	label variable share_green 		"% of incentives that are green sector-oriented"
	label variable share_greening 	"% of incentives that are green process-oriented"
	label variable share_dirty		"% of incentives for polluting sectors"
	label variable total_incentives	"Total number of incentives"
	
	* Create a stacked bar graph with shares

	graph bar share_dirty, over(tax_year, gap(5)) ///
		over(region, gap(5) label(labsize(vsmall))) ///
	    asyvars bar(1, lcolor(none) lwidth(medium)) ///
		bar(1,  color("253 240 237")) ///
		bar(2,  color("249 209 200")) ///
		bar(3,  color("245 178 163")) ///
		bar(4,  color("241 147 126")) ///
		bar(5,  color("237 117 90")) ///
		bar(6,  color("233 86  53")) ///
		bar(7,  color("220 60  24")) ///
		bar(8,  color("184 50  20")) ///
		bar(9,  color("147 40  16")) ///
		bar(10, color("110 30  12")) ///
		bar(11, color("73  20  8")) ///
		bar(12, color("37  10  4")) ///
		legend(order(1 "2009" 2 "2010" 3 "2011" 4 "2012" 5 "2013" 6 "2014" 7 "2015" 8 "2016" 9 "2017" 10 "2018" 11 "2019" 12 "2020") ///
		size(vsmall) pos(6) row(1)) ///
		yscale( lc(white) ) ///
		ylabel(0 "0%" 0.02 "2%" 0.04 "4%" 0.06 "6%" 0.08 "8%" 0.10 "10%" 0.12 "12%",  labsize(vsmall) notick) ///
		ytitle("Share of polluting incentives" "(as a % of total CIT incentives)", margin(-3 0 0 0) size(vsmall) ) ///
		title("Figure 3.6. Prevalence of polluting incentives" "(as a share of total CIT incentives), by region, 2009-20") ///
		plotregion(margin(0 0 0 5))
		
		graph export "$graphs\graph_3_6.png", replace
		putexcel set "$output\Green Paper Output.xlsx", sheet("graphs 3.6") modify
		putexcel A1 = picture("$graphs\graph_3_6.png") 