	****************************************************************************
	*******************	Investment Climate Unit - ETIIC		********************
	*******************	Creation date: September, 10 2024	********************
	*******************	Last version: September, 16 2024	********************
	*******************	Project: Reproducibility Green		********************
	*******************	File: figureC_1.do					********************	
	****************************************************************************
	// Get the current date and format it as YYYYMMDD
	local today = c(current_date)
	local today_formatted = subinstr("`today'", " ", "", .)  // Remove spaces (default format is like "06 Sep 2024")
	local today_formatted = subinstr("`today_formatted'", " ", "", .)  // Ensures no spaces in other date formats
	
	use "$edited_data/Clean GTI GTP Database - `today_formatted'.dta", clear
	
	** Defining the period and regions of analysis
	drop if  tax_year>2020

	gen green = 1 if d_add_green == 1 | d_add_greening == 1
	
	
	collapse (count) other_cond (sum) green d_dirty_polluting_ti, by(tax_year country country_code)
		
	gen share_green = green / other_cond
	gen share_brown = d_dirty_polluting_ti / other_cond
	
	keep if inlist(tax_year, 2009, 2020)
	
	gsort country_code tax_year
	
	bysort country_code: gen dif_green = share_green[_n] - share_green[_n-1]
	bysort country_code: gen dif_brown = share_brown[_n] - share_brown[_n-1]
	drop if tax_year == 2009
	drop tax_year
	
	* Sort the data by dif_green in ascending order
	sort dif_green
	egen order = rank(dif_green), field
	gen  Order = - order

	graph bar dif_green if dif_green!=., over(country, sort(Order) label(labsize(vsmall) angle(90))) ///
	ytitle("Change in share of green incentives" "(as a % of total CIT incentives)", margin(-2 0 0 5) size(vsmall)) ///
	yscale( lc(white) ) ///
	ylabel(-.2 "-20%" -.15 "-15%" -0.1 "-10%" -.05 "-5%" 0 "0%" 0.05 "5%" 0.1 "10%" ///
			0.15 "15%" 0.20 "20%" 0.25 "25%",  labsize(vsmall) notick) ///
    title("Figure C.1. Change in the prevalence of green incentives" "(as a share of total CIT incentives), by economy, 2009–20", size(small)) ///
    bar(1, color("0 100 0")) ///
    plotregion(margin(3 0 0 5))
	
	graph export "$graphs\graph_C_1.png", replace
	putexcel set "$output\Green Paper Output.xlsx", sheet("graphs C.1") modify
	putexcel A1 = picture("$graphs\graph_C_1.png") 
